Riego - Garden-Watering-System

- Using MQTT-Devices and MQTT-Server
- Linux Daemon with Webinterface
- Designed for running on embedded device like Raspberry
- Control from Cloud Server is possible
- Already in production for testing, but Work in progress
- Yet no documentation available


Einstellungen im Dashboard:
- Intervall == 0 => mittgas zusätzlich
- duration == 0 => keine automatische Abschaltung
- aktiviert == 0 => keine automatische Einschaltung
- is_hidden == 0 => keine automatische Ein-/ Ausschaltung